# Changelog

## 0.4.0 (2026-01-29)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** improve OpenAPI spec generation with pre-commit validation ([bd7fb83](https://github.com/kater-ai/kater-python-sdk/commit/bd7fb83370d26957f2ace147d8544b6f78df4160))

## 0.3.0 (2026-01-28)

Full Changelog: [v0.2.1...v0.3.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.2.1...v0.3.0)

### Features

* **api:** manual updates ([0a76475](https://github.com/kater-ai/kater-python-sdk/commit/0a7647569f34ae69b94fed8fc624a2f48e34a049))

## 0.2.1 (2026-01-27)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/kater-ai/kater-python-sdk/compare/v0.2.0...v0.2.1)

## 0.2.0 (2026-01-26)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** switch to oidc based auth ([5de423f](https://github.com/kater-ai/kater-python-sdk/commit/5de423f3de317ffa738613fd438da89df0494110))
* **api:** update stainless config ([095300b](https://github.com/kater-ai/kater-python-sdk/commit/095300b675e3e21df0aa6a0bb8cbec3d368202dd))

## 0.1.0 (2026-01-26)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** update auth params ([e9f46b6](https://github.com/kater-ai/kater-python-sdk/commit/e9f46b611564f4f604de6ded57d5f60a94033ab0))


### Chores

* update SDK settings ([dc43ba4](https://github.com/kater-ai/kater-python-sdk/commit/dc43ba4053472a0962b443bdbc67b16e05ede62b))
* update SDK settings ([333f170](https://github.com/kater-ai/kater-python-sdk/commit/333f170ceaac38dccd8112fcb99915667ad98330))
